<?php

namespace Microsoft\Graph\Generated\Models;

use Microsoft\Kiota\Abstractions\Enum;

class ClickSource extends Enum {
    public const UNKNOWN = "unknown";
    public const QR_CODE = "qrCode";
    public const PHISHING_URL = "phishingUrl";
    public const UNKNOWN_FUTURE_VALUE = "unknownFutureValue";
}
